@@ -16,9 +16,9 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: build-defs.h.in,v 1.9 2002/03/04 09:10:32 imajes Exp $ */
+/* $Id: build-defs.h.in,v 1.11 2002/10/04 04:47:34 rasmus Exp $ */
 
-#define CONFIGURE_COMMAND " './configure' '--prefix=/usr' '--disable-static' '--with-apxs=/usr/sbin/apxs' '--enable-discard-path' '--with-config-file-path=/etc/apache' '--enable-safe-mode' '--with-openssl' '--enable-bcmath' '--with-bz2' '--enable-pic' '--enable-calendar' '--enable-ctype' '--with-gdbm' '--with-db2' '--with-db3' '--with-imap-ssl=/tmp/pine4.44/imap/c-client' '--with-imap=/tmp/pine4.44/imap/c-client' '--enable-dbase' '--enable-ftp' '--enable-gd-imgstrttf' '--with-gd=/tmp/gd-1.8.4' '--with-jpeg-dir=/tmp/gd-1.8.4' '--with-png-dir=/tmp/gd-1.8.4' '--with-gmp' '--with-mysql=/usr' '--with-xml=shared' '--with-mm=/usr' '--enable-trans-sid' '--enable-shmop' '--enable-sockets' '--with-regex=php' '--enable-sysvsem' '--enable-sysvshm' '--enable-yp' '--enable-memory-limit' '--with-tsrm-pthreads' '--enable-shared' '--disable-debug' '--with-zlib=/usr'"
+#define CONFIGURE_COMMAND " './configure' '--prefix=/usr' '--disable-static' '--with-apxs=/usr/sbin/apxs' '--enable-discard-path' '--with-config-file-path=/etc/apache' '--enable-safe-mode' '--with-openssl' '--enable-bcmath' '--with-bz2' '--enable-pic' '--enable-calendar' '--enable-ctype' '--with-gdbm' '--with-db2' '--with-db3' '--with-imap-ssl=/tmp/pine4.52/imap/c-client' '--with-imap=/tmp/pine4.52/imap/c-client' '--enable-dbase' '--enable-ftp' '--enable-gd-imgstrttf' '--with-gd=/tmp/gd-1.8.4' '--with-jpeg-dir=/tmp/gd-1.8.4' '--with-png-dir=/tmp/gd-1.8.4' '--with-gmp' '--with-mysql=shared,/usr' '--with-xml=shared' '--with-mm=/usr' '--enable-trans-sid' '--enable-shmop' '--enable-sockets' '--with-regex=php' '--enable-sysvsem' '--enable-sysvshm' '--enable-yp' '--enable-memory-limit' '--with-tsrm-pthreads' '--enable-shared' '--disable-debug' '--with-zlib=/usr'"
 #define PHP_ADA_INCLUDE		""
 #define PHP_ADA_LFLAGS		""
 #define PHP_ADA_LIBS		""
@@ -27,7 +27,7 @@
 #define PHP_FHTTPD_INCLUDE      ""
 #define PHP_FHTTPD_LIB          ""
 #define PHP_FHTTPD_TARGET       ""
-#define PHP_CFLAGS		"-O2 -march=i386 -mcpu=i686 -prefer-pic"
+#define PHP_CFLAGS		"$(CFLAGS_CLEAN) -prefer-pic"
 #define PHP_DBASE_LIB		""
 #define PHP_BUILD_DEBUG		""
 #define PHP_GDBM_INCLUDE	""
@@ -79,10 +79,13 @@
 #define PHP_BIRDSTEP_LIBS        ""
 #define PEAR_INSTALLDIR         "/usr/lib/php"
 #define PHP_INCLUDE_PATH	".:/usr/lib/php"
-#define PHP_EXTENSION_DIR       "/usr/lib/php/extensions/no-debug-non-zts-20020429"
+#define PHP_EXTENSION_DIR       "/usr/lib/php/extensions"
+#define PHP_PREFIX              "/usr"
 #define PHP_BINDIR              "/usr/bin"
 #define PHP_LIBDIR              "/usr/lib/php"
 #define PHP_DATADIR             "/usr/share/php"
 #define PHP_SYSCONFDIR          "/usr/etc"
 #define PHP_LOCALSTATEDIR       "/usr/var"
 #define PHP_CONFIG_FILE_PATH    "/etc/apache"
+#define PHP_CONFIG_FILE_SCAN_DIR    ""
+#define PHP_SHLIB_SUFFIX        "so"
